@@ -1,6 +1,6 @@
 from .projects import clone_projects
 from .sites import clone_sites
-from .schedules import clone_schedules, clone_schedule_state
+from .schedules import clone_schedules, clone_schedule_state, override_schedule_state
 from .users import clone_users
 from .groups import clone_groups
 from .datasources import clone_datasources
